%define prefix /opt/monitor/op5
%define htmlroot /var/www/html
%define daemon_group apache

Summary: Nagios Configuration Manager - A PHP-based web-frontend for Nagios
Name: monitor-nacoma
Version: %{op5version}
Release: %{op5release}%{?dist}
Group: op5/monitor
License: GPLv2
Source: %name-%version.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}
BuildRequires: doxygen
BuildRequires: monitor-ninja-devel
BuildRequires: php
BuildRequires: python-devel, python
BuildRequires: sed >= 4.0.9

# system.inc.php assumes check_http, check_nrpe:
Requires: plugins-nagios

Requires: httpd
Requires: merlin-apps, merlin
Requires: monitor, /usr/bin/nmap, op5-monitor-supported-database
Requires: monitor-ninja
Requires: monitor-testthis
Requires: nrpe-client
Requires: op5-monitor-user
Requires: op5common >= 1.1.4
Requires: php
Requires: php-op5lib >= 1.1.2-beta3
Requires: php-pdo
Requires: php-snmp, php-gd
Requires: postgresql-server >= 8.4.0 postgresql >= 8.4.0
Requires: sudo
Obsoletes: monitor-op5auth < %{version}
Provides: monitor-op5auth = %{version}

%description
Nacoma is a webbased frontend written in PHP. It's only purpose in life
is to allow easy configuration of Nagios and op5 Monitor. It keeps track
of various dependencies and implements network autodetection features
through the use of nmap and snmpwalk.

Several smart features such as variable propagation and object cloning
exist to facilitate bulk-configuration of large networks.

%package test
Summary: Test files for nacoma
Group: op5/Monitor
BuildRequires: monitor-ninja
Requires: monitor-nacoma = %version
Requires: git
Requires: monitor-management-packs
Requires: monitor-ninja
Requires: monitor-pnp
Requires: op5-mysql
Requires: php-process
Requires: plugins-metadata
Requires: plugins-nagios
Requires: portal

# this one is needed as cuke tests test test this foo with check_icmp
Requires: plugins-op5

# and we test creation of PNP files, so we directories - at least for now
Requires: monitor-pnp

Requires: gcc
Requires: phantomjs
Requires: php-phpunit-PHPUnit
Requires: python-nose
%if 0%{?rhel} <= 6
Requires: ruby20
Requires: ruby20-devel
%else
Requires: ruby
Requires: ruby-devel
%endif


%description test
Misc test files for nacoma.


%prep
%setup -q

%build
make docs
make all


%install
rm -rf %buildroot
umask 022
mkdir -p -m 755 %buildroot%prefix/nacoma
mkdir -p %buildroot%_bindir
cp asmonitor.sh %buildroot%_bindir/asmonitor

mkdir -p -m 755 %buildroot%prefix/ninja/modules/
cp -a nacoma %buildroot%prefix/ninja/modules/
cp -a legacy_nacoma %buildroot%prefix/ninja/modules/

# set the version
sed -i include/config.inc.php \
	-e 's/@VERSION@/%{version}-%{release}/' \
	-e 's/DEBUG = true;$/DEBUG = false;/'

dst=%buildroot%prefix/nacoma
cp *.php *.sh "$dst"

# install interesting top-level directories not starting with a dot
for src in Documentation \
	sql include images templates data hooks docs api js css classes \
	Makefile scripts test
do
	cp -a "$src" "$dst"
done

chmod 644 $(find "$dst" -type f)
chmod 755 $(find "$dst" -type f -name "*.sh")
chmod 755 $(find "$dst" -type d)

chmod 755 %buildroot%prefix/nacoma/snmp_runner.php

mkdir -p %buildroot/etc/cron.d/
install -m 644 autoscan_scheduler.crontab %buildroot/etc/cron.d/autoscan-scheduler

install -d %buildroot%{python_sitelib}/nacoma
install -pm 0644 pylib/hooks.py %buildroot%{python_sitelib}/nacoma/
install -pm 0644 pylib/__init__.py %buildroot%{python_sitelib}/nacoma/

install -d %buildroot/etc/sudoers.d
install -pm 0440 asmonitor.sudo %buildroot/etc/sudoers.d/asmonitor

%post
# Verify that mysql-server is installed and running before executing sql scripts
# TODO: Is it really a good idea to hide mysql errors?
$(mysql -Be "quit" 2>/dev/null)
if [ $? -eq 0 ]; then
	sh %prefix/nacoma/sql/install-mysql.sh
else
  echo "WARNING: mysql-server is either not installed or not running."
  echo "You need to manually run database install/upgrade procedures"
  echo "to complete the setup of %name"
fi
chown root:root /usr/bin/nmap >& /dev/null || :
chmod 4711 /usr/bin/nmap >& /dev/null || :

# create a config-only backup named after the version we're installing
if test -f /opt/monitor/etc/nagios.cfg; then
	path=%{htmlroot}/backup
	if ! test -d $path; then
		mkdir -p $path
	fi
	chown monitor:%daemon_group "$path"
	chmod 775 "$path"
	date=$(date "+%Y-%m-%d_%H.%M")
	bupname=$path/nacoma-pre-%version-upgrade-$date.tar.gz
	echo "Backing up your configuration to $bupname"
	tar czfP "$bupname" /opt/monitor/etc \
		$(sed -ne 's#^cfg_[^=]*=\([^/].*\)#/opt/monitor/etc/\1#p' \
			-e 's#^resource_file=\([^/].*\)#/opt/monitor/etc/\1#p' \
			-e 's#^resource_file=\(/.*\)#\1#' \
			-e 's#^cfg_[^=]*=\(/.*\)#\1#p' \
			/opt/monitor/etc/nagios.cfg | grep -v ^/opt/monitor/etc)
fi

if ! grep -q "includedir" /etc/sudoers; then
	echo "#includedir /etc/sudoers.d" >> /etc/sudoers
fi

%files
%defattr(-,root,root)
%prefix/nacoma
# %prefix/webconfig
%attr(755,root,root) %prefix/nacoma/hooks/save/docu_msg_hook.py
%attr(755,root,root) %_bindir/asmonitor
%attr(644,root,root) /etc/cron.d/*
%{python_sitelib}/nacoma/
/etc/sudoers.d/asmonitor

%prefix/ninja/modules/nacoma
%prefix/ninja/modules/legacy_nacoma

%exclude %prefix/nacoma/Makefile
%exclude %prefix/nacoma/test
%exclude %prefix/nacoma/Documentation

%files test
%defattr(644,monitor,%daemon_group,755)
%prefix/nacoma/Makefile
%prefix/nacoma/test
%prefix/nacoma/Documentation

%clean
rm -rf %buildroot

%changelog
* Mon Mar  8 2010 Andreas Ericsson <ae@op5.se>
- Install API documentation

* Wed Jun 17 2009 Andreas Ericsson <ae@op5.se>
- Rename database to 'nacoma'
- Change install path to %%prefix/nacoma

* Tue Oct 21 2008 Andreas Ericsson <ae@op5.se>
- Rewrote sections "install" and "files"

* Mon Aug 25 2008 Andreas Ericsson <ae@op5.se>
- Removed TODO file from install

* Thu Aug 14 2008 Andreas Ericsson <ae@op5.se>
- Added %suprog.

* Fri Mar  3 2006 Andreas Ericsson <ae@op5.se> auto-versioned
- Build packages using git-tar-tree and a build-script.

* Mon Nov 28 2005 Andreas Ericsson <ae@op5.se> 2.6.3-op5.1
- Updated to version 2.6.3.
- Package from tar-ball (git makes it *easy*).

* Mon Aug 15 2005 Andreas Ericsson <ae@op5.se> 2.6.1-op5.1
- Several minor bugfixes. See bugtracker for details.
- Changed nmap permissions to root:root 4711

* Fri Jun 17 2005 Andreas Ericsson <ae@op5.se> 2.6.0-op5.2
- Minor fixes for *dependency and *escalation handling.

* Tue Sep 14 2004 Andreas Ericsson <ae@op5.se>
- Version upgrade to 2.4.0.
- Changelog maintained in CVS.

* Mon Jun 14 2004 Andreas Ericsson <ae@op5.se>
- Added Requires tag.
- Removed php's .ini-files.

* Mon May 3 2004 Andreas Ericsson <ae@op5.se>
- Fixed files section.

* Tue Apr 27 2004 Andreas Ericsson <ae@op5.se>
- Initial RPM Package
